[Compare the full difference.](https://github.com/callowayproject/bump-my-version/compare/1.1.4...1.2.0)

### Fixes

- Fix broken link to API. [4591652](https://github.com/callowayproject/bump-my-version/commit/459165294f1318756758ebfa7baec4e4f44edd42)
    
  **https:** //callowayproject.github.io/bump-my-version/reference/api/ is 404.

### New

- Add support for short commit SHA in SCM information and hooks. [ee83f99](https://github.com/callowayproject/bump-my-version/commit/ee83f996f107fea1a6ab876f0afec99721aa21b7)
    
### Other

- [pre-commit.ci] pre-commit autoupdate. [7f9e5c1](https://github.com/callowayproject/bump-my-version/commit/7f9e5c1613e3deb151a6123193a916d68713f519)
    
  **updates:** - [github.com/astral-sh/ruff-pre-commit: v0.11.10 → v0.11.12](https://github.com/astral-sh/ruff-pre-commit/compare/v0.11.10...v0.11.12)

- [pre-commit.ci] pre-commit autoupdate. [d3169af](https://github.com/callowayproject/bump-my-version/commit/d3169af8006f513815c4e26763965e6cf1b1b7d0)
    
  **updates:** - [github.com/astral-sh/ruff-pre-commit: v0.11.9 → v0.11.10](https://github.com/astral-sh/ruff-pre-commit/compare/v0.11.9...v0.11.10)

### Updates

- Update Dockerfile and action metadata for enhanced GitHub Actions compatibility. [6baf7f7](https://github.com/callowayproject/bump-my-version/commit/6baf7f793de7b23f37b130bd6e47cf6d3e5df595)
    
